@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lbjp-common.gss/src/glite_gss.c,v 1.25 2012/08/10 13:23:02 valtri Exp $"
+#ident "$Header: /cvs/glite/org.glite.lbjp-common.gss/src/glite_gss.c,v 1.27 2012/08/23 13:28:14 mvocu Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -156,6 +156,7 @@ static void callback_ares_gethostbyname(void *arg, int status, struct hostent *h
 			arp->ent->h_length = h->h_length;
 			arp->err = NETDB_SUCCESS;
 		break;
+	    case ARES_ENODATA:
 	    case ARES_EBADNAME:
 	    case ARES_ENOTFOUND:
 		arp->err = HOST_NOT_FOUND;
@@ -693,14 +694,15 @@ int
 edg_wll_gss_acquire_cred_gsi(const char *cert_file, const char *key_file, edg_wll_GssCred *cred,
 			 edg_wll_GssStatus* gss_code)
 {
-	return edg_wll_gss_acquire_cred(cert_file, key_file, cred, gss_code);
+	return edg_wll_gss_acquire_cred(cert_file, key_file, GSS_C_BOTH, cred, gss_code);
 }
 
 /** Load or reload credentials. It should be called regularly (credential files can be changed).
  @see edg_wll_gss_watch_creds
  */
 int
-edg_wll_gss_acquire_cred(const char *cert_file, const char *key_file, edg_wll_GssCred *cred,
+edg_wll_gss_acquire_cred(const char *cert_file, const char *key_file, const gss_cred_usage_t cred_usage,
+			 edg_wll_GssCred *cred,
 			 edg_wll_GssStatus* gss_code)
 {
    OM_uint32 major_status = 0, minor_status, minor_status2;
@@ -746,7 +748,7 @@ edg_wll_gss_acquire_cred(const char *cert_file, const char *key_file, edg_wll_Gs
       mechs.elements = get_oid(mech_name);
       
       major_status = gss_acquire_cred(&minor_status, GSS_C_NO_NAME, 0,
-	    			      &mechs, GSS_C_BOTH,
+	    			      &mechs, cred_usage,
 				      &gss_cred, NULL, NULL);
       if (GSS_ERROR(major_status)) {
 	 ret = EDG_WLL_GSS_ERROR_GSS;
